# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: deepproto/proto/common/v1/common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&deepproto/proto/common/v1/common.proto\x12\x19\x64\x65\x65pproto.proto.common.v1\"\x84\x02\n\x08\x41nyValue\x12\x16\n\x0cstring_value\x18\x01 \x01(\tH\x00\x12\x14\n\nbool_value\x18\x02 \x01(\x08H\x00\x12\x13\n\tint_value\x18\x03 \x01(\x03H\x00\x12\x16\n\x0c\x64ouble_value\x18\x04 \x01(\x01H\x00\x12<\n\x0b\x61rray_value\x18\x05 \x01(\x0b\x32%.deepproto.proto.common.v1.ArrayValueH\x00\x12?\n\x0ckvlist_value\x18\x06 \x01(\x0b\x32\'.deepproto.proto.common.v1.KeyValueListH\x00\x12\x15\n\x0b\x62ytes_value\x18\x07 \x01(\x0cH\x00\x42\x07\n\x05value\"A\n\nArrayValue\x12\x33\n\x06values\x18\x01 \x03(\x0b\x32#.deepproto.proto.common.v1.AnyValue\"C\n\x0cKeyValueList\x12\x33\n\x06values\x18\x01 \x03(\x0b\x32#.deepproto.proto.common.v1.KeyValue\"K\n\x08KeyValue\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.deepproto.proto.common.v1.AnyValueBT\n\"com.intergral.deep.proto.common.v1P\x01Z,github.com/intergral/go-deep-proto/common/v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'deepproto.proto.common.v1.common_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"com.intergral.deep.proto.common.v1P\001Z,github.com/intergral/go-deep-proto/common/v1'
  _ANYVALUE._serialized_start=70
  _ANYVALUE._serialized_end=330
  _ARRAYVALUE._serialized_start=332
  _ARRAYVALUE._serialized_end=397
  _KEYVALUELIST._serialized_start=399
  _KEYVALUELIST._serialized_end=466
  _KEYVALUE._serialized_start=468
  _KEYVALUE._serialized_end=543
# @@protoc_insertion_point(module_scope)
