# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: deepproto/proto/resource/v1/resource.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from deepproto.proto.common.v1 import common_pb2 as deepproto_dot_proto_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*deepproto/proto/resource/v1/resource.proto\x12\x1b\x64\x65\x65pproto.proto.resource.v1\x1a&deepproto/proto/common/v1/common.proto\"e\n\x08Resource\x12\x37\n\nattributes\x18\x01 \x03(\x0b\x32#.deepproto.proto.common.v1.KeyValue\x12 \n\x18\x64ropped_attributes_count\x18\x02 \x01(\rBX\n$com.intergral.deep.proto.resource.v1P\x01Z.github.com/intergral/go-deep-proto/resource/v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'deepproto.proto.resource.v1.resource_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$com.intergral.deep.proto.resource.v1P\001Z.github.com/intergral/go-deep-proto/resource/v1'
  _RESOURCE._serialized_start=115
  _RESOURCE._serialized_end=216
# @@protoc_insertion_point(module_scope)
